@@ -26,7 +26,7 @@
 
     extern attribute attr[MAXIMUM_WIDGET_COUNT];
 
-    void load_graph_properties(Agraph_t * graph);	//load from graph to gui
+    void load_graph_properties(void);	//load from graph to gui
 
     void load_attributes(void);	//loads attributes from a text file
 
