@@ -36,6 +36,7 @@
 #include <stddef.h>
 #include <string>
 #include <vector>
+#include "openFile.h"
 
 extern "C" {
 #ifdef GVDLL
@@ -105,18 +106,6 @@ static void usage(int v)
     graphviz_exit(v);
 }
 
-static FILE *openFile(const char *name)
-{
-    FILE *fp;
-
-    fp = fopen(name, "w");
-    if (!fp) {
-	std::cerr << "gvpack: could not open file " << name << " for writing\n";
-	graphviz_exit(1);
-    }
-    return (fp);
-}
-
 /* setNameValue:
  * If arg is a name-value pair, add it to the list
  * and return 0; otherwise, return 1.
@@ -201,7 +190,7 @@ static void init(int argc, char *argv[], pack_info* pinfo)
 	case 'o':
 	    if (outfp != nullptr)
 		fclose(outfp);
-	    outfp = openFile(optarg);
+	    outfp = openFile("gvpack", optarg, "w");
 	    break;
 	case 'u':
 	    pinfo->mode = l_undef;
@@ -439,7 +428,7 @@ fillGraph(Agraph_t * g, Dt_t * d,
 	  Agsym_t *(*setf)(Agraph_t*, char*, const char*), size_t cnt) {
     attr_t *av;
     for (av = (attr_t *) dtflatten(d); av;
-	 av = (attr_t *) dtlink(d, (Dtlink_t *) av)) {
+	 av = (attr_t *)dtlink(d, av)) {
 	if (cnt == av->cnt)
 	    setf(g, av->name, av->value);
 	else
