@@ -77,6 +77,7 @@
 #include <stdbool.h>
 #include <stdio.h>
 #include <cghdr.h>
+#include <cgraph/alloc.h>
 #include <cgraph/unreachable.h>
 #include <stddef.h>
 extern void aagerror(const char*);
@@ -138,7 +139,7 @@ static	Agdisc_t	*Disc;		/* discipline passed to agread or agconcat */
 static gstack_t *S;
 
 
-#line 142 "grammar.c" /* yacc.c:339  */
+#line 143 "grammar.c" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -212,13 +213,13 @@ extern int aagdebug;
 
 union AAGSTYPE
 {
-#line 86 "../../lib/cgraph/grammar.y" /* yacc.c:355  */
+#line 87 "../../lib/cgraph/grammar.y" /* yacc.c:355  */
 
 			int				i;
 			char			*str;
 			struct Agnode_s	*n;
 
-#line 222 "grammar.c" /* yacc.c:355  */
+#line 223 "grammar.c" /* yacc.c:355  */
 };
 
 typedef union AAGSTYPE AAGSTYPE;
@@ -235,7 +236,7 @@ int aagparse (void);
 
 /* Copy the second part of user declarations.  */
 
-#line 239 "grammar.c" /* yacc.c:358  */
+#line 240 "grammar.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -533,13 +534,13 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,   103,   103,   104,   105,   108,   110,   113,   113,   115,
-     115,   117,   117,   119,   119,   121,   121,   123,   123,   125,
-     126,   129,   133,   133,   135,   135,   135,   136,   140,   140,
-     142,   143,   144,   147,   148,   151,   152,   153,   156,   157,
-     160,   160,   162,   164,   165,   167,   170,   170,   172,   175,
-     178,   181,   181,   184,   185,   186,   189,   189,   189,   191,
-     192,   195,   196
+       0,   104,   104,   105,   106,   109,   111,   114,   114,   116,
+     116,   118,   118,   120,   120,   122,   122,   124,   124,   126,
+     127,   130,   134,   134,   136,   136,   136,   137,   141,   141,
+     143,   144,   145,   148,   149,   152,   153,   154,   157,   158,
+     161,   161,   163,   165,   166,   168,   171,   171,   173,   176,
+     179,   182,   182,   185,   186,   187,   190,   190,   190,   192,
+     193,   196,   197
 };
 #endif
 
@@ -1364,217 +1365,217 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 103 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 104 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {freestack(); endgraph();}
-#line 1370 "grammar.c" /* yacc.c:1646  */
+#line 1371 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 3:
-#line 104 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 105 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {if (G) {freestack(); endgraph(); agclose(G); G = Ag_G_global = NULL;}}
-#line 1376 "grammar.c" /* yacc.c:1646  */
+#line 1377 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 6:
-#line 110 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 111 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {startgraph((yyvsp[0].str),(yyvsp[-1].i) != 0,(yyvsp[-2].i) != 0);}
-#line 1382 "grammar.c" /* yacc.c:1646  */
+#line 1383 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 7:
-#line 113 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 114 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str)=(yyvsp[0].str);}
-#line 1388 "grammar.c" /* yacc.c:1646  */
+#line 1389 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 8:
-#line 113 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 114 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str)=0;}
-#line 1394 "grammar.c" /* yacc.c:1646  */
+#line 1395 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 9:
-#line 115 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 116 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.i)=1;}
-#line 1400 "grammar.c" /* yacc.c:1646  */
+#line 1401 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 10:
-#line 115 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 116 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.i)=0;}
-#line 1406 "grammar.c" /* yacc.c:1646  */
+#line 1407 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 11:
-#line 117 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 118 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.i) = 0;}
-#line 1412 "grammar.c" /* yacc.c:1646  */
+#line 1413 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 12:
-#line 117 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 118 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.i) = 1;}
-#line 1418 "grammar.c" /* yacc.c:1646  */
+#line 1419 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 21:
-#line 130 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 131 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {if ((yyvsp[-1].i)) endedge(); else endnode();}
-#line 1424 "grammar.c" /* yacc.c:1646  */
+#line 1425 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 24:
-#line 135 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 136 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {getedgeitems();}
-#line 1430 "grammar.c" /* yacc.c:1646  */
+#line 1431 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 25:
-#line 135 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 136 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {getedgeitems();}
-#line 1436 "grammar.c" /* yacc.c:1646  */
+#line 1437 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 26:
-#line 135 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 136 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.i) = 1;}
-#line 1442 "grammar.c" /* yacc.c:1646  */
+#line 1443 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 27:
-#line 136 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 137 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.i) = 0;}
-#line 1448 "grammar.c" /* yacc.c:1646  */
+#line 1449 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 30:
-#line 142 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 143 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {appendnode((yyvsp[0].str),NULL,NULL);}
-#line 1454 "grammar.c" /* yacc.c:1646  */
+#line 1455 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 31:
-#line 143 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 144 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {appendnode((yyvsp[-2].str),(yyvsp[0].str),NULL);}
-#line 1460 "grammar.c" /* yacc.c:1646  */
+#line 1461 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 32:
-#line 144 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 145 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {appendnode((yyvsp[-4].str),(yyvsp[-2].str),(yyvsp[0].str));}
-#line 1466 "grammar.c" /* yacc.c:1646  */
+#line 1467 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 33:
-#line 147 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 148 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {attrstmt((yyvsp[-2].i),(yyvsp[-1].str));}
-#line 1472 "grammar.c" /* yacc.c:1646  */
+#line 1473 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 34:
-#line 148 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 149 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {attrstmt(T_graph,NULL);}
-#line 1478 "grammar.c" /* yacc.c:1646  */
+#line 1479 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 35:
-#line 151 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 152 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.i) = T_graph;}
-#line 1484 "grammar.c" /* yacc.c:1646  */
+#line 1485 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 36:
-#line 152 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 153 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.i) = T_node;}
-#line 1490 "grammar.c" /* yacc.c:1646  */
+#line 1491 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 37:
-#line 153 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 154 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.i) = T_edge;}
-#line 1496 "grammar.c" /* yacc.c:1646  */
+#line 1497 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 38:
-#line 156 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 157 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str) = (yyvsp[-1].str);}
-#line 1502 "grammar.c" /* yacc.c:1646  */
+#line 1503 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 39:
-#line 157 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 158 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str) = NULL; }
-#line 1508 "grammar.c" /* yacc.c:1646  */
+#line 1509 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 48:
-#line 172 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 173 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {appendattr((yyvsp[-2].str),(yyvsp[0].str));}
-#line 1514 "grammar.c" /* yacc.c:1646  */
+#line 1515 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 49:
-#line 175 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 176 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {appendattr((yyvsp[0].str),NULL);}
-#line 1520 "grammar.c" /* yacc.c:1646  */
+#line 1521 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 51:
-#line 181 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 182 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {opensubg((yyvsp[0].str));}
-#line 1526 "grammar.c" /* yacc.c:1646  */
+#line 1527 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 52:
-#line 181 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 182 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {closesubg();}
-#line 1532 "grammar.c" /* yacc.c:1646  */
+#line 1533 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 53:
-#line 184 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 185 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str)=(yyvsp[0].str);}
-#line 1538 "grammar.c" /* yacc.c:1646  */
+#line 1539 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 54:
-#line 185 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 186 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str)=NULL;}
-#line 1544 "grammar.c" /* yacc.c:1646  */
+#line 1545 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 55:
-#line 186 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 187 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str)=NULL;}
-#line 1550 "grammar.c" /* yacc.c:1646  */
+#line 1551 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 59:
-#line 191 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 192 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str) = (yyvsp[0].str);}
-#line 1556 "grammar.c" /* yacc.c:1646  */
+#line 1557 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 60:
-#line 192 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 193 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str) = (yyvsp[0].str);}
-#line 1562 "grammar.c" /* yacc.c:1646  */
+#line 1563 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 61:
-#line 195 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 196 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str) = (yyvsp[0].str);}
-#line 1568 "grammar.c" /* yacc.c:1646  */
+#line 1569 "grammar.c" /* yacc.c:1646  */
     break;
 
   case 62:
-#line 196 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
+#line 197 "../../lib/cgraph/grammar.y" /* yacc.c:1646  */
     {(yyval.str) = concat((yyvsp[-2].str),(yyvsp[0].str));}
-#line 1574 "grammar.c" /* yacc.c:1646  */
+#line 1575 "grammar.c" /* yacc.c:1646  */
     break;
 
 
-#line 1578 "grammar.c" /* yacc.c:1646  */
+#line 1579 "grammar.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1802,7 +1803,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 198 "../../lib/cgraph/grammar.y" /* yacc.c:1906  */
+#line 199 "../../lib/cgraph/grammar.y" /* yacc.c:1906  */
 
 
 static item *newitem(int tag, void *p0, char *p1)
@@ -2045,7 +2046,7 @@ concat (char* s1, char* s2)
   size_t len = strlen(s1) + strlen(s2) + 1;
 
   if (len <= BUFSIZ) sym = buf;
-  else sym = malloc(len);
+  else sym = gv_alloc(len);
   strcpy(sym,s1);
   strcat(sym,s2);
   s = agstrdup (G,sym);
@@ -2066,7 +2067,7 @@ concatPort (char* s1, char* s2)
   size_t len = strlen(s1) + strlen(s2) + 2;  /* one more for ':' */
 
   if (len <= BUFSIZ) sym = buf;
-  else sym = malloc(len);
+  else sym = gv_alloc(len);
   sprintf (sym, "%s:%s", s1, s2);
   s = agstrdup (G,sym);
   agstrfree (G,s1);
