@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,13 +5,13 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
-#include    "circular.h"
-#include    "blocktree.h"
-#include    "circpos.h"
+#include    <circogen/circular.h>
+#include    <circogen/blocktree.h>
+#include    <circogen/circpos.h>
 #include	<string.h>
 
 #define		MINDIST			1.0
@@ -51,16 +48,6 @@ static void initGraphAttrs(Agraph_t * g, circ_state * state)
     state->rootname = rootname;
 }
 
-/* cleanup:
- * We need to cleanup objects created in initGraphAttrs
- * and all blocks. All graph objects are components of the
- * initial derived graph and will be freed when it is closed. 
- */
-static void cleanup(block_t * root, circ_state * sp)
-{
-    freeBlocktree(root);
-}
-
 static block_t*
 createOneBlock(Agraph_t * g, circ_state * state)
 {
@@ -69,7 +56,7 @@ createOneBlock(Agraph_t * g, circ_state * state)
     block_t *bp;
     Agnode_t* n;
 
-    sprintf(name, "_block_%d", state->blockCount++);
+    snprintf(name, sizeof(name), "_block_%d", state->blockCount++);
     subg = agsubg(g, name, 1);
     bp = mkBlock(subg);
 
@@ -109,7 +96,12 @@ void circularLayout(Agraph_t * g, Agraph_t* realg)
 	root = createBlocktree(g, &state);
     circPos(g, root, &state);
 
-    cleanup(root, &state);
+    /* cleanup:
+     * We need to cleanup objects created in initGraphAttrs
+     * and all blocks. All graph objects are components of the
+     * initial derived graph and will be freed when it is closed.
+     */
+    freeBlocktree(root);
 }
 
 #ifdef DEBUG
@@ -149,8 +141,10 @@ void prData(Agnode_t * n, int pass)
 	pname = "<P0>";
     if (BLOCK(n))
 	bname = agnameof(BLOCK(n)->sub_graph);
-    else
+    else {
 	pname = "<B0>";
+    bname = "";
+    }
     fprintf(stderr, "%s: %x %s %s ", agnameof(n), FLAGS(n), pname, bname);
     switch (pass) {
     case 0:
