@@ -488,7 +488,8 @@ static void _dot_splines(graph_t * g, int normalize)
 		free (edgelist);
 	}
 	else if (agtail(e0) == aghead(e0)) {
-	    int b, sizey, r;
+	    int b, r;
+	    double sizey;
 	    n = agtail(e0);
 	    r = ND_rank(n);
 	    if (r == GD_maxrank(g)) {
@@ -501,8 +502,8 @@ static void _dot_splines(graph_t * g, int normalize)
 		sizey = ND_coord(n).y - ND_coord(GD_rank(g)[r+1].v[0]).y;
 	    }
 	    else {
-		int upy = ND_coord(GD_rank(g)[r-1].v[0]).y - ND_coord(n).y;
-		int dwny = ND_coord(n).y - ND_coord(GD_rank(g)[r+1].v[0]).y;
+		double upy = ND_coord(GD_rank(g)[r-1].v[0]).y - ND_coord(n).y;
+		double dwny = ND_coord(n).y - ND_coord(GD_rank(g)[r+1].v[0]).y;
 		sizey = MIN(upy, dwny);
 	    }
 	    makeSelfEdge(edges, ind, cnt, sd.Multisep, sizey / 2, &sinfo);
@@ -1278,7 +1279,8 @@ make_flat_adj_edges(graph_t* g, edge_t** edges, int ind, int cnt, edge_t* e0,
     graph_t* subg;
     node_t *auxt, *auxh;
     edge_t* auxe;
-    int     i, j, midx, midy, leftx, rightx;
+    int     i, j;
+    double midx, midy, leftx, rightx;
     pointf   del;
     edge_t* hvye = NULL;
     attr_state_t* attrs;
@@ -1466,7 +1468,7 @@ make_flat_labeled_edge(graph_t* g, spline_info_t* sp, path* P, edge_t* e, int et
     bool ps_needs_free = false;
     pathend_t tend, hend;
     boxf lb;
-    int i, pn, ydelta;
+    int i, pn;
     edge_t *f;
     pointf points[7];
 
@@ -1496,8 +1498,8 @@ make_flat_labeled_edge(graph_t* g, spline_info_t* sp, path* P, edge_t* e, int et
 	lb.LL.x = ND_coord(ln).x - ND_lw(ln);
 	lb.UR.x = ND_coord(ln).x + ND_rw(ln);
 	lb.UR.y = ND_coord(ln).y + ND_ht(ln)/2;
-	ydelta = ND_coord(ln).y - GD_rank(g)[ND_rank(tn)].ht1 -
-		ND_coord(tn).y + GD_rank(g)[ND_rank(tn)].ht2;
+	double ydelta = ND_coord(ln).y - GD_rank(g)[ND_rank(tn)].ht1 -
+	                ND_coord(tn).y + GD_rank(g)[ND_rank(tn)].ht2;
 	ydelta /= 6;
 	lb.LL.y = lb.UR.y - MAX(5,ydelta);
 
