@@ -135,8 +135,6 @@ static void neato_cleanup_graph(graph_t * g)
 	free_scan_graph(g);
 	free(GD_clust(g));
     }
-    if (g != agroot(g))
-        agclean(g, AGRAPH , "Agraphinfo_t");
 }
 
 void neato_cleanup(graph_t * g)
@@ -1234,7 +1232,7 @@ majorization(graph_t *mg, graph_t * g, int nv, int mode, int model, int dim, adj
 	    fprintf (stderr, "\n");
 	    dumpOpts (&opt, nv);
 #endif
-            rv = stress_majorization_cola(gp, nv, ne, coords, nodes, Ndim, model, MaxIter, &opt);
+            rv = stress_majorization_cola(gp, nv, coords, nodes, Ndim, model, MaxIter, &opt);
 	    freeClusterData(cs);
 	    free (nsize);
         }
