@@ -1,6 +1,3 @@
-/* $Id: tree_map.h,v 1.1 2011/02/15 17:45:08 erg Exp $Revision: */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,21 +5,18 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#ifndef TREE_MAP_H
-#define TREE_MAP_H
+#pragma once
 
-#include <SparseMatrix.h>
+#include <sparse/SparseMatrix.h>
 
 typedef struct rectangle_struct {
-  real x[2];/* center */
-  real size[2]; /* total width/height*/
+  double x[2];/* center */
+  double size[2]; /* total width/height*/
 } rectangle;
 
-extern rectangle* tree_map(int n, real *area, rectangle fillrec);
+extern rectangle* tree_map(int n, double *area, rectangle fillrec);
 
-extern rectangle rectangle_new(real x, real y, real width, real height);
-
-#endif
+extern rectangle rectangle_new(double x, double y, double width, double height);
