@@ -16,7 +16,7 @@
 #include <stddef.h>
 #include <stdbool.h>
 
-Multilevel_control Multilevel_control_new(int scheme, int mode){
+Multilevel_control Multilevel_control_new(void) {
   Multilevel_control ctrl;
 
   ctrl = GNEW(struct Multilevel_control_struct);
@@ -24,17 +24,9 @@ Multilevel_control Multilevel_control_new(int scheme, int mode){
   ctrl->min_coarsen_factor = 0.75;
   ctrl->maxlevel = 1<<30;
   ctrl->randomize = TRUE;
-  /* now set in spring_electrical_control_new(), as well as by command line argument -c
-    ctrl->coarsen_scheme = COARSEN_INDEPENDENT_EDGE_SET_HEAVEST_CLUSTER_PERNODE_LEAVES_FIRST;
-    ctrl->coarsen_scheme = COARSEN_INDEPENDENT_VERTEX_SET_RS;
-    ctrl->coarsen_scheme = COARSEN_INDEPENDENT_EDGE_SET_HEAVEST_EDGE_PERNODE;
-    ctrl->coarsen_scheme = COARSEN_HYBRID;
-    ctrl->coarsen_scheme = COARSEN_INDEPENDENT_EDGE_SET_HEAVEST_EDGE_PERNODE_SUPERNODES_FIRST;
-    ctrl->coarsen_mode = COARSEN_MODE_FORCEFUL; or COARSEN_MODE_GENTLE;
-  */
 
-  ctrl->coarsen_scheme = scheme;
-  ctrl->coarsen_mode = mode;
+  ctrl->coarsen_scheme = COARSEN_INDEPENDENT_EDGE_SET_HEAVEST_EDGE_PERNODE_SUPERNODES_FIRST;
+  ctrl->coarsen_mode = COARSEN_MODE_FORCEFUL;
   return ctrl;
 }
 
@@ -329,7 +321,7 @@ static void maximal_independent_edge_set_heavest_edge_pernode_leaves_first(Spars
   double *a, amax = 0;
   int first = TRUE, jamax = 0;
   int *matched, nz, ncmax = 0, nz0, nzz,k ;
-  enum {UNMATCHED = -2, MATCHED = -1};
+  enum {MATCHED = -1};
 
   assert(A);
   assert(SparseMatrix_known_strucural_symmetric(A));
@@ -505,7 +497,7 @@ static void maximal_independent_edge_set_heavest_edge_pernode_supernodes_first(S
   double *a, amax = 0;
   int first = TRUE, jamax = 0;
   int *matched, nz, nz0;
-  enum {UNMATCHED = -2, MATCHED = -1};
+  enum {MATCHED = -1};
   int  nsuper, *super = NULL, *superp = NULL;
 
   assert(A);
@@ -648,7 +640,7 @@ static void maximal_independent_edge_set_heavest_cluster_pernode_leaves_first(Sp
   (void)n;
   double *a;
   int *matched, nz,  nz0, nzz,k, nv;
-  enum {UNMATCHED = -2, MATCHED = -1};
+  enum {MATCHED = -1};
   double *vlist;
 
   assert(A);
