@@ -11,7 +11,6 @@
 #include <sparse/LinkedList.h>
 #include <sfdpgen/PriorityQueue.h>
 #include <common/memory.h>
-#include <common/logic.h>
 #include <assert.h>
 #include <common/arith.h>
 #include <stddef.h>
@@ -96,7 +95,7 @@ int PriorityQueue_pop(PriorityQueue q, int *i, int *gain){
   *gain = gain_max = q->gain_max;
   (q->count)--;
   l = (q->buckets)[gain_max];
-  data = (int*) DoubleLinkedList_get_data(l);
+  data = DoubleLinkedList_get_data(l);
   *i = data[0];
 
   DoubleLinkedList_delete_element(l, free, &((q->buckets)[gain_max]));
