@@ -16,6 +16,7 @@
 #include <sfdpgen/sparse_solve.h>
 #include <time.h>
 #include <sfdpgen/uniform_stress.h>
+#include <stdbool.h>
 
 /* uniform stress solves the model:
 
@@ -25,14 +26,15 @@ This is somewhat similar to the binary stress model
 
 */
 
-UniformStressSmoother UniformStressSmoother_new(int dim, SparseMatrix A, double *x, double alpha, double M, int *flag){
+static UniformStressSmoother UniformStressSmoother_new(SparseMatrix A,
+                                                       double alpha, double M) {
   UniformStressSmoother sm;
   int i, j, k, m = A->m, *ia = A->ia, *ja = A->ja, *iw, *jw, *id, *jd;
   int nz;
-  double *d, *w, *a = (double*) A->a;
+  double *d, *w, *a = A->a;
   double diag_d, diag_w, dist, epsilon = 0.01;
 
-  assert(SparseMatrix_is_symmetric(A, FALSE));
+  assert(SparseMatrix_is_symmetric(A, false));
 
   sm = MALLOC(sizeof(struct StressMajorizationSmoother_struct));
   sm->data = NULL;
@@ -56,7 +58,8 @@ UniformStressSmoother UniformStressSmoother_new(int dim, SparseMatrix A, double
 
   iw = sm->Lw->ia; jw = sm->Lw->ja;
   id = sm->Lwd->ia; jd = sm->Lwd->ja;
-  w = (double*) sm->Lw->a; d = (double*) sm->Lwd->a;
+  w = sm->Lw->a;
+  d = sm->Lwd->a;
   iw[0] = id[0] = 0;
 
   nz = 0;
@@ -112,11 +115,11 @@ static SparseMatrix get_distance_matrix(SparseMatrix A, double scaling){
   int i;
 
   if (A->type == MATRIX_TYPE_REAL){
-    B = SparseMatrix_symmetrize(A, FALSE);
+    B = SparseMatrix_symmetrize(A, false);
   } else {
     B = SparseMatrix_get_real_adjacency_matrix_symmetrized(A);
   }
-  val = (double*) B->a;
+  val = B->a;
   if (scaling != 1) for (i = 0; i < B->nz; i++) val[i] *= scaling;
   return B;
 }
@@ -156,21 +159,21 @@ void uniform_stress(int dim, SparseMatrix A, double *x, int *flag){
   }
 
   B = get_distance_matrix(A, scaling);
-  assert(SparseMatrix_is_symmetric(B, FALSE));
+  assert(SparseMatrix_is_symmetric(B, false));
 
-  sm = UniformStressSmoother_new(dim, B, x, 1000000*lambda0, M, flag);
+  sm = UniformStressSmoother_new(B, 1000000*lambda0, M);
   UniformStressSmoother_smooth(sm, dim, x, maxit);
   UniformStressSmoother_delete(sm);
 
-  sm = UniformStressSmoother_new(dim, B, x, 10000*lambda0, M, flag);
+  sm = UniformStressSmoother_new(B, 10000*lambda0, M);
   UniformStressSmoother_smooth(sm, dim, x, maxit);
   UniformStressSmoother_delete(sm);
 
-  sm = UniformStressSmoother_new(dim, B, x, 100*lambda0, M, flag);
+  sm = UniformStressSmoother_new(B, 100*lambda0, M);
   UniformStressSmoother_smooth(sm, dim, x, maxit);
   UniformStressSmoother_delete(sm);
 
-  sm = UniformStressSmoother_new(dim, B, x, lambda0, M, flag);
+  sm = UniformStressSmoother_new(B, lambda0, M);
   UniformStressSmoother_smooth(sm, dim, x, maxit);
   UniformStressSmoother_delete(sm);
 
