@@ -161,10 +161,9 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 		    if (*t_str != '*')
 			n_str = (form - 1) - t_str;
 		    else {
-			t_str = (*_Sffmtintf) (t_str + 1, &n);
+			t_str = _Sffmtintf(t_str + 1, &n);
 			if (*t_str == '$') {
-			    if (!fp && !(fp = (*_Sffmtposf)
-					 (f, oform, oargs, 0)))
+			    if (!fp && !(fp = _Sffmtposf(f, oform, oargs, 0)))
 				goto pop_fmt;
 			    n = FP_SET(n, argn);
 			} else
@@ -176,7 +175,7 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 			} else if (ft && ft->extf) {
 			    FMTSET(ft, form, args,
 				   LEFTP, 0, 0, 0, 0, 0, NULL, 0);
-			    n = (*ft->extf)(&argv, ft);
+			    n = ft->extf(&argv, ft);
 			    if (n < 0)
 				goto pop_fmt;
 			    if (!(ft->flags & SFFMT_VALUE))
@@ -245,10 +244,10 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 	  do_star:
 	    form += 1;		/* fall through */
 	case '*':
-	    form = (*_Sffmtintf) (form, &n);
+	    form = _Sffmtintf(form, &n);
 	    if (*form == '$') {
 		form += 1;
-		if (!fp && !(fp = (*_Sffmtposf) (f, oform, oargs, 0)))
+		if (!fp && !(fp = _Sffmtposf(f, oform, oargs, 0)))
 		    goto pop_fmt;
 		n = FP_SET(n, argn);
 	    } else
@@ -259,7 +258,7 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 	    else if (ft && ft->extf) {
 		FMTSET(ft, form, args, '.', dot, 0, 0, 0, 0, NULL,
 		       0);
-		if ((*ft->extf)(&argv, ft) < 0)
+		if (ft->extf(&argv, ft) < 0)
 		    goto pop_fmt;
 		if (ft->flags & SFFMT_VALUE)
 		    v = argv.i;
@@ -283,7 +282,7 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 		v = v * 10 + (*form - '0');
 	    if (*form == '$') {
 		form += 1;
-		if (!fp && !(fp = (*_Sffmtposf) (f, oform, oargs, 0)))
+		if (!fp && !(fp = _Sffmtposf(f, oform, oargs, 0)))
 		    goto pop_fmt;
 		argp = v - 1;
 		goto loop_flags;
@@ -307,10 +306,10 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 		for (n = *form; isdigit(n); n = *++form)
 		    size = size * 10 + (n - '0');
 	    } else if (*form == '*') {
-		form = (*_Sffmtintf) (form + 1, &n);
+		form = _Sffmtintf(form + 1, &n);
 		if (*form == '$') {
 		    form += 1;
-		    if (!fp && !(fp = (*_Sffmtposf) (f, oform, oargs, 0)))
+		    if (!fp && !(fp = _Sffmtposf(f, oform, oargs, 0)))
 			goto pop_fmt;
 		    n = FP_SET(n, argn);
 		} else
@@ -321,7 +320,7 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 		else if (ft && ft->extf) {
 		    FMTSET(ft, form, args, 'I', sizeof(int), 0, 0, 0, 0,
 			   NULL, 0);
-		    if ((*ft->extf)(&argv, ft) < 0)
+		    if (ft->extf(&argv, ft) < 0)
 			goto pop_fmt;
 		    if (ft->flags & SFFMT_VALUE)
 			size = argv.i;
@@ -397,7 +396,7 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 		   t_str, n_str);
 	    SFEND(f);
 	    SFOPEN(f, 0);
-	    v = (*ft->extf)(&argv, ft);
+	    v = ft->extf(&argv, ft);
 	    SFLOCK(f, 0);
 	    SFBUF(f);
 
@@ -447,15 +446,14 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 
 	case '!':		/* stacking a new environment */
 	    if (!fp)
-		fp = (*_Sffmtposf) (f, oform, oargs, 0);
+		fp = _Sffmtposf(f, oform, oargs, 0);
 	    else
 		goto pop_fmt;
 
 	    if (!argv.ft)
 		goto pop_fmt;
 	    if (!argv.ft->form && ft) {	/* change extension functions */
-		if (ft->eventf &&
-		    (*ft->eventf) (f, SF_DPOP, (void *) form, ft) < 0)
+		if (ft->eventf && ft->eventf(f, SF_DPOP, (void *) form, ft) < 0)
 		    continue;
 		fmstk->ft = ft = argv.ft;
 	    } else {		/* stack a new environment */
@@ -960,8 +958,8 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
     while ((fm = fmstk)) {	/* pop the format stack and continue */
 	if (fm->eventf) {
 	    if (!form || !form[0])
-		(*fm->eventf) (f, SF_FINAL, NULL, ft);
-	    else if ((*fm->eventf) (f, SF_DPOP, (void *) form, ft) < 0)
+		fm->eventf(f, SF_FINAL, NULL, ft);
+	    else if (fm->eventf(f, SF_DPOP, (void *) form, ft) < 0)
 		goto loop_fmt;
 	}
 
@@ -983,7 +981,7 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
     free(fp);
     while ((fm = fmstk)) {
 	if (fm->eventf)
-	    (*fm->eventf) (f, SF_FINAL, NULL, fm->ft);
+	    fm->eventf(f, SF_FINAL, NULL, fm->ft);
 	fmstk = fm->next;
 	free(fm);
     }
@@ -997,7 +995,7 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 
     if ((((flags = f->flags) & SF_SHARE) && !(flags & SF_PUBLIC)) ||
 	(n > 0 && (d == (uchar *) data || (flags & SF_LINE))))
-	(void) SFWRITE(f, (void *) d, n);
+	(void) SFWRITE(f, d, n);
     else
 	f->next += n;
 
