@@ -27,13 +27,13 @@
 #include <gvc/gvplugin_render.h>
 #include <gvc/gvplugin_device.h>
 #include <cgraph/agxbuf.h>
+#include <cgraph/alloc.h>
+#include <cgraph/unreachable.h>
 #include <common/utils.h>
 #include <gvc/gvc.h>
 #include <gvc/gvio.h>
 #include <gvc/gvcint.h>
 
-#include <common/memory.h>
-
 typedef enum {
 	FORMAT_JSON,
 	FORMAT_JSON0,
@@ -43,9 +43,8 @@ typedef enum {
 
 typedef struct {
     int Level;
-    boolean isLatin;
-    boolean doXDot;
-    boolean Attrs_not_written_flag;
+    bool isLatin;
+    bool doXDot;
 } state_t;
 
 typedef struct {
@@ -158,12 +157,11 @@ static void set_attrwf(Agraph_t * g, bool toplevel, bool value)
 
 static void write_polyline (GVJ_t * job, xdot_polyline* polyline)
 {
-    int i;
-    int cnt = polyline->cnt;
+    const size_t cnt = polyline->cnt;
     xdot_point* pts = polyline->pts;
 
     gvprintf(job, "\"points\": [");
-    for (i = 0; i < cnt; i++) {
+    for (size_t i = 0; i < cnt; i++) {
 	if (i > 0) gvprintf(job, ",");
 	gvprintf(job, "[%.03f,%.03f]", pts[i].x, pts[i].y);
     }
@@ -297,6 +295,8 @@ static void write_xdot (xdot_op * op, GVJ_t * job, state_t* sp)
  	indent(job, sp->Level);
 	gvprintf(job, "\"fontchar\": %d\n", op->u.fontchar);
 	break;
+    default:
+	UNREACHABLE();
     }
     sp->Level--;
     indent(job, sp->Level);
@@ -306,7 +306,6 @@ static void write_xdot (xdot_op * op, GVJ_t * job, state_t* sp)
 static void write_xdots (char * val, GVJ_t * job, state_t* sp)
 {
     xdot* cmds;
-    int i;
 
     if (!val || *val == '\0') return;
 
@@ -319,7 +318,7 @@ static void write_xdots (char * val, GVJ_t * job, state_t* sp)
     gvputs(job, "\n");
     indent(job, sp->Level++);
     gvputs(job, "[\n");
-    for (i = 0; i < cmds->cnt; i++) {
+    for (size_t i = 0; i < cmds->cnt; i++) {
 	if (i > 0)
 	    gvputs(job, ",\n");
 	write_xdot (cmds->ops+i, job, sp);
@@ -476,7 +475,7 @@ static int write_edges(Agraph_t * g, GVJ_t * job, int top, state_t* sp)
         return 0;
     }
 
-    Agedge_t **edges = gcalloc(count, sizeof(Agedge_t *));
+    Agedge_t **edges = gv_calloc(count, sizeof(Agedge_t *));
 
     size_t i = 0;
     for (Agnode_t *np = agfstnode(g); np; np = agnxtnode(g, np)) {
@@ -614,7 +613,7 @@ static void insert (Dt_t* map, char* name, int v)
 	    agerr(AGWARN, "Duplicate cluster name \"%s\"\n", name);
 	return;
     }
-    ip = calloc(1, sizeof(intm));
+    ip = gv_alloc(sizeof(intm));
     ip->id = strdup(name);
     ip->v = v;
     dtinsert (map, ip);
@@ -712,7 +711,6 @@ static void json_end_graph(GVJ_t *job)
     sp.Level = 0;
     sp.isLatin = GD_charset(g) == CHAR_LATIN1;
     sp.doXDot = job->render.id == FORMAT_JSON || job->render.id == FORMAT_XDOT_JSON;
-    sp.Attrs_not_written_flag = 0;
     write_graph(g, job, TRUE, &sp);
 }
 
